==> haskell-deque-0.4.4.1-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deque
version:              0.4.4.1
visibility:           public
id:                   deque-0.4.4.1-GaHZ3rlob6u3qGEcsDZYCZ
key:                  deque-0.4.4.1-GaHZ3rlob6u3qGEcsDZYCZ
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  e559c0edd568f983cb7efa25344dee36
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.2.8/site-local/deque-0.4.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/deque-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.1-GaHZ3rlob6u3qGEcsDZYCZ
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb mtl-2.2.2
    strict-list-0.1.7.6-ElkgckEJVU0KjHtqxyk5Iu

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deque-0.4.4.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deque
version:              0.4.4.1
visibility:           public
id:                   deque-0.4.4.1-GGPGGgTqmReFvLxFKgs4TM
key:                  deque-0.4.4.1-GGPGGgTqmReFvLxFKgs4TM
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  237d2a0f852e573cd9ccbd010c0a11c9
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.2.8/site-local/deque-0.4.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/deque-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.1-GGPGGgTqmReFvLxFKgs4TM
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb mtl-2.2.2
    strict-list-0.1.7.6-2qk1KrjfoIgE4SKd80LKtt

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
